@@ -34,14 +34,11 @@ int main(int argc, char** argv)
     KLocalizedString::setApplicationDomain("okular");
 
     KAboutData aboutData = okularAboutData();
-
-    app.setApplicationName(aboutData.applicationData().componentName());
-    app.setApplicationDisplayName(aboutData.applicationData().displayName());
-    app.setApplicationVersion(aboutData.version());
-    app.setOrganizationDomain(QStringLiteral("kde.org"));
+    KAboutData::setApplicationData(aboutData);
+    // set icon for shells which do not use desktop file metadata
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("okular")));
 
     QCommandLineParser parser;
-    KAboutData::setApplicationData(aboutData);
     // The KDE4 version accepted flags such as -unique with a single dash -> preserve compatibility
     parser.setSingleDashWordOptionMode(QCommandLineParser::ParseAsLongOptions);
     parser.addVersionOption();
